@@ -1,4 +1,7 @@
-def openapi(return_class=None, description=None, path_parameters=None, parameters=None, body=None):
+def openapi(
+        return_class=None, description=None, path_parameters=None, parameters=None, body=None, answer_content=None,
+        tags=None
+):
     def decorate(f):
         def wrapper(*args, **kwargs):
             if len(args) == 1:
@@ -8,7 +11,9 @@ def openapi(return_class=None, description=None, path_parameters=None, parameter
                         'description': description,
                         'path_parameters': path_parameters,
                         "parameters": parameters,
-                        "body": body
+                        "body": body,
+                        "answer_content": answer_content,
+                        'tags': tags
                     }
             return f(*args, **kwargs)
         return wrapper
